@@ -13,7 +13,7 @@ def list_projects():
     r = make_request(url)
     data = r.json()['data']
     for j in data:
-        del (j['relationships'])
+        del j['relationships']
     print(json.dumps(data))
     return
 
@@ -32,8 +32,8 @@ def create_project_export_file(project_id, raw, worker_data):
                 "projectId": f'{project_id}',
                 "type": 'raw' if raw else 'target',
                 "allJudgements": worker_data and not raw,
-                "includeWorkerData": worker_data and not raw
-            }
+                "includeWorkerData": worker_data and not raw,
+            },
         }
     }
 
