@@ -1,7 +1,6 @@
 import requests
 
-from tasq_cli import settings
-from tasq_cli.settings import SERVER, TOKEN
+from tasq_cli import settings, credentials
 
 logger = None
 
@@ -11,26 +10,26 @@ def make_request(url, post_data={}, files={}, headers={}, json={}):
     if not logger:
         logger = settings.get_logger()
     logger.info(f'request url={url} headers={headers} post_data={post_data} json={json}')
-    full_url = SERVER + url
+    full_url = settings.SERVER + url
     headers = headers.copy()
-    headers['Authorization'] = f'BEARER {TOKEN}'
+    headers['Authorization'] = f'BEARER {credentials.TOKEN}'
     if post_data or files:
         r = requests.post(
             full_url,
             headers=headers,
-            data = post_data,
-            files = files,
+            data=post_data,
+            files=files,
         )
     elif json:
         r = requests.post(
             full_url,
             headers=headers,
-            json=json
+            json=json,
         )
     else:
         r = requests.get(
             full_url,
-            headers=headers
+            headers=headers,
         )
     if not 200 <= r.status_code < 400:
         logger.error(f"request failed with statue {r.status_code}, text {r.text}")
