@@ -8,6 +8,5 @@ def detail_source_file(source_file_id):
     url = f'/source_files/{source_file_id}?'
     r = make_request(url)
     data = r.json()['data']
-    del(data['relationships'])
+    del data['relationships']
     return data
-
