@@ -1,6 +1,6 @@
-import requests
 import json
-
+import warnings
+import requests
 from tasq_cli import credentials
 from tasq_cli.settings import SERVER, get_logger
 
@@ -11,8 +11,10 @@ HEADERS = {
 }
 
 
-def add_bulk_tag(tag, **query_params):
+def add_tag_bulk(tag, **query_params):
+    warnings.warn("deprecated", DeprecationWarning)
     query = '&'.join([f'filter%5B{param[0]}%5D={param[1]}' for param in query_params.items()])
+    query = json.dumps(query)
     headers = HEADERS
     headers['accept'] = 'application/vnd.api+json'
     headers['Content-type'] = 'application/x-www-form-urlencoded'
@@ -23,6 +25,7 @@ def add_bulk_tag(tag, **query_params):
 
 
 def add_tags(tag, **query_params):
+    warnings.warn("deprecated", DeprecationWarning)
     query = '/?' + '&'.join([f'filter%5B{param[0]}%5D={param[1]}' for param in query_params.items()])
     query = query + '&page%5Bsize%5D=5000'
     url = f'{SERVER}/project_resources{query}'
@@ -42,6 +45,7 @@ def add_tags(tag, **query_params):
 
 
 def add_tag(project_resource_id, current_tags, tag, batch_id, step_id):
+    warnings.warn("deprecated", DeprecationWarning)
     url = f"{SERVER}/project_resources/{project_resource_id}"
     headers = HEADERS
     headers['accept'] = 'application/vnd.api+json'
