@@ -87,18 +87,29 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
                 'cdn_url': settings.CDN_URL.format(object_name=object_name),
             }
             if not settings.dry:
-                response = client.put_object(
-                    Body=image_wrapper,
-                    Bucket=credentials.BUCKET,
-                    Key=object_name,
-                    ContentMD5=content_md5,
-                    # TODO this is questionable
-                    # we might not want to make these
-                    # public in the long term
-                    # ACL='public-read'
-                    # NOTE
-                    # consider that sync might work faster than put_object
-                )
+                if ext in ['pdf']:
+                    response = client.put_object(
+                        Body=image_wrapper,
+                        Bucket=credentials.BUCKET,
+                        Key=object_name,
+                        ContentMD5=content_md5,
+                        ContentType=f"application/{ext}",
+                        ContentDisposition="inline",
+                        # TODO this is questionable
+                        # we might not want to make these
+                        # public in the long term
+                        # ACL='public-read'
+                        # NOTE
+                        # consider that sync might work faster than put_object
+                    )
+                else:
+                    response = client.put_object(
+                        Body=image_wrapper,
+                        Bucket=credentials.BUCKET,
+                        Key=object_name,
+                        ContentMD5=content_md5,
+                        # see above ToDo
+                    )
                 if response['ResponseMetadata']['HTTPStatusCode'] == 200 and response['ETag'] == f'"{md5_hash}"':
                     tag_response = client.put_object_tagging(
                         Bucket=credentials.BUCKET,
